# DICL-Flow

## Original code

[https://github.com/jytime/DICL-Flow](https://github.com/jytime/DICL-Flow)

## Code license

See [https://github.com/jytime/DICL-Flow/issues/4](https://github.com/jytime/DICL-Flow/issues/4).

## Pretrained weights license

Not specified.

## Citation

```
@article{wang2020displacement,
  title={Displacement-Invariant Matching Cost Learning for Accurate Optical Flow Estimation},
  author={Wang, Jianyuan and Zhong, Yiran and Dai, Yuchao and Zhang, Kaihao and Ji, Pan and Li, Hongdong},
  journal={Advances in Neural Information Processing Systems},
  volume={33},
  year={2020}
}
```